/** model of acivity scores factor levels with rsidual component scores **/

data {
  int N;  //number of obs
  int Q;  //number of phenotypes
  int M;  //number of studies
  
  vector[N] Adjustment;
  int<lower=1> Phenotype[N];
  int<lower=1> Study[N];
  vector<lower=1>[N] nobs;  //sample size of each observation
  
  //informative priors for residuals
  real<lower=0> logsigmaloc;
  real<lower=0> logsigmascale;
}
transformed data {
  vector[N] y;
  y = Adjustment - 100;
}
parameters {
  vector[Q] phenotypes;
  vector[M] studies;
  real logsigmastudies;
  
  real logsigma_within;
  real logsigma_betw;
}
transformed parameters {
  real sigma_within;    //within
  real sigma_betw;      //between
  vector[N] dispersion; //sum between and within
  real sigmastudies;
  vector[N] f;          //linear predictor

  sigma_within = exp(logsigma_within);
  sigma_betw   = exp(logsigma_betw);
  dispersion = sqrt(sigma_within^2 ./ nobs + sigma_betw^2);
  
  sigmastudies = exp(logsigmastudies);
  
  f = phenotypes[Phenotype] + studies[Study];
}
model {
  phenotypes ~ normal(0, 20);
  studies ~ normal(0, sigmastudies);
  //sigmastudies ~ cauchy(0, 35);
  logsigmastudies ~ normal(2, 0.25);
  
  //model for dispersion datapoints of studies
  logsigma_within ~ normal(logsigmaloc, logsigmascale);
  logsigma_betw   ~ normal(logsigmaloc, logsigmascale);

  //model
  y ~ normal(f, dispersion);
}
