/** model of acivity scores (one regressor, no icpt) with residual component scores and covariates **/

data {
  int N;  //number of obs
  int K;  //number of covariats
  int M;  //number of studies
  
  vector[N] Adjustment;
  vector[N] Activity;
  matrix[N, K] Covariates;
  int<lower=1> Study[N];
  
  vector<lower=1>[N] nobs;  //sample size of each observation
  
  //informative priors for residuals
  real<lower=0> logsigmaloc;
  real<lower=0> logsigmascale;
}
transformed data {
  vector[N] y;
  y = Adjustment - 100;
}
parameters {
  real activity;
  vector[K] covcoefs;
  vector[M] studies;
  //real<lower=0> sigmastudies;
  real logsigmastudies;
  
  real logsigma_within;
  real logsigma_betw;
}
transformed parameters {
  real sigma_within;
  real sigma_betw;
  vector[N] dispersion;
  real sigmastudies;
  vector[N] f;

  sigma_within = exp(logsigma_within);
  sigma_betw   = exp(logsigma_betw);
  dispersion = sqrt(sigma_within^2 ./ nobs + sigma_betw^2);
  
  sigmastudies = exp(logsigmastudies);
  
  f = Activity * activity + Covariates * covcoefs + studies[Study];
}
model {
  activity ~ normal(0, 20);
  studies ~ normal(0, sigmastudies);
  //sigmastudies ~ cauchy(0, 35);
  logsigmastudies ~ normal(2, 0.25);
  
  //model for dispersion datapoints of studies
  logsigma_within ~ normal(logsigmaloc, logsigmascale);
  logsigma_betw   ~ normal(logsigmaloc, logsigmascale);

  //model
  y ~ normal(f, dispersion);
}
